@@ -288,9 +288,10 @@ class Campaign:
         """
         if self.osm:
             for line in self.osm.railway_lines:
-                coords = line.to_ipyleaflet()
-                file_polyline = Polyline(locations=coords, color=line.color, fill=False, weight=4)
-                m.add_layer(file_polyline)
+                for track in line.tracks:
+                    coords = track.to_ipyleaflet()
+                    file_polyline = Polyline(locations=coords, color=line.color, fill=False, weight=4)
+                    m.add_layer(file_polyline)
         else:
             logger.warning("No OSM region downloaded!")
 
