@@ -5,6 +5,7 @@ from typing import List
 
 import networkx as nx
 import overpy
+from ipyleaflet import Map, ScaleControl, FullScreenControl, Polyline, Circle, LayerGroup
 
 from pyridy import config
 from pyridy.osm.utils import convert_lon_lat_to_xy, calc_curvature, calc_distance_from_lon_lat
@@ -198,6 +199,10 @@ class OSMRelation:
         logger.debug("Number of individual tracks: %d" % len(self.tracks))
 
         self.color = relation.tags.get("colour", generate_random_color("HEX")) if not color else color
+        self.lon_sw = min([float(n.lon) for n in self.nodes])
+        self.lon_ne = max([float(n.lon) for n in self.nodes])
+        self.lat_sw = min([float(n.lat) for n in self.nodes])
+        self.lat_ne = max([float(n.lat) for n in self.nodes])
 
     def to_ipyleaflef(self) -> List[list]:
         """
@@ -212,6 +217,39 @@ class OSMRelation:
         else:
             return [[]]
 
+    def create_map(self, show_result_nodes: bool = False) -> Map:
+        center = ((self.lat_sw + self.lat_ne) / 2, (self.lon_sw + self.lon_ne) / 2)
+
+        m = Map(center=center, zoom=12, scroll_wheel_zoom=True, basemap=config.OPEN_STREET_MAP_DE)
+        m.add_control(ScaleControl(position='bottomleft'))
+        m.add_control(FullScreenControl())
+
+        # Add map
+        m.add_layer(config.OPEN_RAILWAY_MAP)
+
+        for track in self.tracks:
+            coords = track.to_ipyleaflet()
+            file_polyline = Polyline(locations=coords, color=self.color, fill=False, weight=4)
+            m.add_layer(file_polyline)
+
+        if show_result_nodes:
+            nodes = list(itertools.chain.from_iterable([w.attributes.get("results", []) for w in self.ways]))
+            circles = []
+            for n in nodes:
+                circle = Circle()
+                circle.location = n.lon, n.lat
+                circle.radius = 2
+                circle.color = "#CC071E"
+                circle.fill_color = "#CC071E"
+                circle.weight = 3
+                circle.fill_opacity = 0.1
+                circles.append(circle)
+
+            l_circles = LayerGroup(layers=circles)
+            m.add_layer(l_circles)
+
+        return m
+
 
 class OSMRailwayLine(OSMRelation):
     def __init__(self, relation: overpy.Relation, ways: List[overpy.Way] = None, color=None):
